@@ -17,7 +17,7 @@
   copies.
 */
 
-/*$RCSfile: gdevpdfu.c,v $ $Revision: 1.12.2.1 $ */
+/*$RCSfile: gdevpdfu.c,v $ $Revision: 1.12.2.2 $ */
 /* Output utilities for PDF-writing driver */
 #include "memory_.h"
 #include "jpeglib_.h"		/* for sdct.h */
@@ -85,7 +85,7 @@ pdf_open_document(gx_device_pdf * pdev)
 	pprintd2(s, "%%PDF-%d.%d\n", level / 10, level % 10);
 	pdev->binary_ok = !pdev->params.ASCII85EncodePages;
 	if (pdev->binary_ok)
-	    pputs(s, "%\307\354\217\242\n");
+	    stream_puts(s, "%\307\354\217\242\n");
     }
     /*
      * Determine the compression method.  Currently this does nothing.
@@ -174,7 +174,7 @@ pdf_begin_obj(gx_device_pdf * pdev)
 int
 pdf_end_obj(gx_device_pdf * pdev)
 {
-    pputs(pdev->strm, "endobj\n");
+    stream_puts(pdev->strm, "endobj\n");
     return 0;
 }
 
@@ -208,7 +208,7 @@ none_to_stream(gx_device_pdf * pdev)
     pprintld1(s, "<</Length %ld 0 R", pdev->contents_length_id);
     if (pdev->compression == pdf_compress_Flate)
 	pprints1(s, "/Filter /%s", compression_filter_name);
-    pputs(s, ">>\nstream\n");
+    stream_puts(s, ">>\nstream\n");
     pdev->contents_pos = pdf_stell(pdev);
     if (pdev->compression == pdf_compress_Flate) {	/* Set up the Flate filter. */
 	const stream_template *template = &compression_filter_template;
@@ -245,7 +245,7 @@ none_to_stream(gx_device_pdf * pdev)
 	}
     }
     /* Do a level of gsave for the clipping path. */
-    pputs(s, "q\n");
+    stream_puts(s, "q\n");
     return PDF_IN_STREAM;
 }
 /* Enter text context from stream context. */
@@ -273,7 +273,7 @@ private int
 string_to_text(gx_device_pdf * pdev)
 {
     pdf_put_string(pdev, pdev->text.buffer, pdev->text.buffer_count);
-    pputs(pdev->strm, (pdev->text.use_leading ? "'\n" : "Tj\n"));
+    stream_puts(pdev->strm, (pdev->text.use_leading ? "'\n" : "Tj\n"));
     pdev->text.use_leading = false;
     pdev->text.buffer_count = 0;
     return PDF_IN_TEXT;
@@ -282,7 +282,7 @@ string_to_text(gx_device_pdf * pdev)
 private int
 text_to_stream(gx_device_pdf * pdev)
 {
-    pputs(pdev->strm, "ET Q\n");
+    stream_puts(pdev->strm, "ET Q\n");
     pdf_reset_text(pdev);	/* because of Q */
     return PDF_IN_STREAM;
 }
@@ -302,7 +302,7 @@ stream_to_none(gx_device_pdf * pdev)
 	pdev->strm = s = fs;
     }
     length = pdf_stell(pdev) - pdev->contents_pos;
-    pputs(s, "endstream\n");
+    stream_puts(s, "endstream\n");
     pdf_end_obj(pdev);
     pdf_open_obj(pdev, pdev->contents_length_id);
     pprintld1(s, "%ld\n", length);
@@ -335,7 +335,7 @@ pdf_close_contents(gx_device_pdf * pdev, bool last)
 	return 0;
     if (last) {			/* Exit from the clipping path gsave. */
 	pdf_open_contents(pdev, PDF_IN_STREAM);
-	pputs(pdev->strm, "Q\n");
+	stream_puts(pdev->strm, "Q\n");
 	pdev->text.font = 0;
     }
     return pdf_open_contents(pdev, PDF_IN_NONE);
@@ -507,7 +507,7 @@ pdf_copy_data(stream *s, FILE *file, long count)
 	uint copy = min(left, sbuf_size);
 
 	fread(buf, 1, sbuf_size, file);
-	pwrite(s, buf, copy);
+	stream_write(s, buf, copy);
 	left -= copy;
     }
 }
@@ -566,7 +566,7 @@ int
 pdf_write_saved_string(gx_device_pdf * pdev, gs_string * pstr)
 {
     if (pstr->data != 0) {
-	pwrite(pdev->strm, pstr->data, pstr->size);
+	stream_write(pdev->strm, pstr->data, pstr->size);
 	gs_free_string(pdev->pdf_memory, pstr->data, pstr->size,
 		       "pdf_write_saved_string");
 	pstr->data = 0;
@@ -605,11 +605,11 @@ pdf_put_matrix(gx_device_pdf * pdev, const char *before,
     stream *s = pdev->strm;
 
     if (before)
-	pputs(s, before);
+	stream_puts(s, before);
     pprintg6(s, "%g %g %g %g %g %g ",
 	     pmat->xx, pmat->xy, pmat->yx, pmat->yy, pmat->tx, pmat->ty);
     if (after)
-	pputs(s, after);
+	stream_puts(s, after);
 }
 
 /*
@@ -622,7 +622,7 @@ pdf_put_name_escaped(stream *s, const byte *nstr, uint size, bool escape)
 {
     uint i;
 
-    pputc(s, '/');
+    stream_putc(s, '/');
     for (i = 0; i < size; ++i) {
 	uint c = nstr[i];
 	char hex[4];
@@ -632,14 +632,14 @@ pdf_put_name_escaped(stream *s, const byte *nstr, uint size, bool escape)
 		/* These are valid in 1.1, but must be escaped in 1.2. */
 		if (escape) {
 		    sprintf(hex, "#%02x", c);
-		    pputs(s, hex);
+		    stream_puts(s, hex);
 		    break;
 		}
 		/* falls through */
 	    default:
 		if (c >= 0x21 && c <= 0x7e) {
 		    /* These are always valid. */
-		    pputc(s, c);
+		    stream_putc(s, c);
 		    break;
 		}
 		/* falls through */
@@ -653,13 +653,13 @@ pdf_put_name_escaped(stream *s, const byte *nstr, uint size, bool escape)
 		/* but can be escaped in 1.2. */
 		if (escape) {
 		    sprintf(hex, "#%02x", c);
-		    pputs(s, hex);
+		    stream_puts(s, hex);
 		    break;
 		}
 		/* falls through */
 	    case 0:
 		/* This is invalid in 1.1 and 1.2, and cannot be escaped. */
-		pputc(s, '?');
+		stream_putc(s, '?');
 	}
     }
 }
@@ -689,7 +689,7 @@ pdf_write_value(const gx_device_pdf * pdev, const byte * vstr, uint size)
     if (size > 0 && vstr[0] == '/')
 	pdf_put_name(pdev, vstr + 1, size - 1);
     else
-	pwrite(pdev->strm, vstr, size);
+	stream_write(pdev->strm, vstr, size);
 }
 
 /* Store filters for a stream. */
@@ -829,7 +829,7 @@ pdf_begin_data(gx_device_pdf *pdev, pdf_data_writer_t *pdw)
 	filters |= USE_ASCII85;
     if (pdev->CompatibilityLevel >= 1.2)
 	filters |= USE_FLATE;
-    pputs(s, fnames[filters]);
+    stream_puts(s, fnames[filters]);
     pprintld1(s, "/Length %ld 0 R>>stream\n", length_id);
     code = psdf_begin_binary((gx_device_psdf *)pdev, &pdw->binary);
     if (code < 0)
@@ -853,7 +853,7 @@ pdf_end_data(pdf_data_writer_t *pdw)
 
     if (code < 0)
 	return code;
-    pputs(pdev->strm, "\nendstream\n");
+    stream_puts(pdev->strm, "\nendstream\n");
     pdf_end_separate(pdev);
     pdf_open_separate(pdev, pdw->length_id);
     pprintld1(pdev->strm, "%ld\n", length);
@@ -912,7 +912,7 @@ pdf_function(gx_device_pdf *pdev, const gs_function_t *pfn,
 		count = min(sizeof(buf), info.data_size - pos);
 		data_source_access_only(info.DataSource, pos, count, buf,
 					&ptr);
-		pwrite(writer.strm, ptr, count);
+		stream_write(writer.strm, ptr, count);
 	    }
 	    code = psdf_end_binary(&writer);
 	    sclose(s);
