@@ -17,7 +17,7 @@
   copies.
 */
 
-/*$RCSfile: gdevpdfw.c,v $ $Revision: 1.5.2.2 $ */
+/*$RCSfile: gdevpdfw.c,v $ $Revision: 1.5.2.3 $ */
 /* Font writing for pdfwrite driver. */
 #include "memory_.h"
 #include "string_.h"
@@ -59,10 +59,10 @@ pdf_write_CIDSystemInfo(gx_device_pdf *pdev,
 {
     stream *s = pdev->strm;
 
-    pputs(s, "/CISystemInfo<<\n/Registry");
+    stream_puts(s, "/CISystemInfo<<\n/Registry");
     s_write_ps_string(s, pcidsi->Registry.data, pcidsi->Registry.size,
 		      PRINT_HEX_NOT_OK);
-    pputs(s, "\n/Ordering");
+    stream_puts(s, "\n/Ordering");
     s_write_ps_string(s, pcidsi->Ordering.data, pcidsi->Ordering.size,
 		      PRINT_HEX_NOT_OK);
     pprintd1(s, "\n/Supplement %d\n>>\n", pcidsi->Supplement);
@@ -79,7 +79,7 @@ pdf_write_Widths(gx_device_pdf *pdev, int first, int last,
     pprintd2(s, "/FirstChar %d/LastChar %d/Widths[", first, last);
     for (i = first; i <= last; ++i)
 	pprintd1(s, (i & 15 ? " %d" : "\n%d"), widths[i]);
-    pputs(s, "]\n");
+    stream_puts(s, "]\n");
     return 0;
 }
 
@@ -121,7 +121,7 @@ pdf_write_synthesized_type3(gx_device_pdf *pdev, const pdf_font_t *pef)
 	const pdf_char_proc_t *pcp;
 	int w;
 
-	pputs(s, "<<");
+	stream_puts(s, "<<");
 	/* Write real characters. */
 	for (pcp = pef->char_procs; pcp; pcp = pcp->char_next) {
 	    bbox.p.y = min(bbox.p.y, pcp->y_offset);
@@ -141,13 +141,13 @@ pdf_write_synthesized_type3(gx_device_pdf *pdev, const pdf_font_t *pef)
 		widths[ch] = w + X_SPACE_MIN;
 	    }
 	}
-	pputs(s, ">>");
+	stream_puts(s, ">>");
     }
 
     pdf_write_font_bbox(pdev, &bbox);
-    pputs(s, "/FontMatrix[1 0 0 1 0 0]");
+    stream_puts(s, "/FontMatrix[1 0 0 1 0 0]");
     pdf_write_Widths(pdev, 0, pef->num_chars - 1, widths);
-    pputs(s, ">>\n");
+    stream_puts(s, ">>\n");
     pdf_end_separate(pdev);
     return 0;
 }
@@ -175,8 +175,8 @@ pdf_write_FontDescriptor(gx_device_pdf *pdev, const pdf_font_descriptor_t *pfd)
 	    /****** ADD COMPRESSION + ASCII85 ******/
 	    pprintd1(s, "<</Length %d>>stream\n", (int)pfd->chars_used.size);
 	    for (i = 0; i < pfd->chars_used.size; ++i)
-		pputc(s, byte_reverse_bits[pfd->chars_used.data[i]]);
-	    pputs(s, "endstream\n");
+		stream_putc(s, byte_reverse_bits[pfd->chars_used.data[i]]);
+	    stream_puts(s, "endstream\n");
 	    pdf_end_separate(pdev);
 	}
 	default:
@@ -185,7 +185,7 @@ pdf_write_FontDescriptor(gx_device_pdf *pdev, const pdf_font_descriptor_t *pfd)
     }
     pdf_open_separate(pdev, pdf_font_descriptor_id(pfd));
     s = pdev->strm;
-    pputs(s, "<</Type/FontDescriptor/FontName");
+    stream_puts(s, "<</Type/FontDescriptor/FontName");
     pdf_put_name(pdev, pfd->FontName.chars, pfd->FontName.size);
     if (font) {		/* not a built-in font */
 	param_printer_params_t params;
@@ -246,7 +246,7 @@ pdf_write_FontDescriptor(gx_device_pdf *pdev, const pdf_font_descriptor_t *pfd)
 						     pfd->chars_used.data);
 		int i;
 
-		pputs(s, "/CharSet(");
+		stream_puts(s, "/CharSet(");
 		for (i = 0; i < subset_size; ++i) {
 		    uint len;
 		    const char *str = font->procs.callbacks.glyph_name
@@ -257,7 +257,7 @@ pdf_write_FontDescriptor(gx_device_pdf *pdev, const pdf_font_descriptor_t *pfd)
 				      (const byte *)".notdef", 7))
 			pdf_put_name(pdev, (const byte *)str, len);
 		}
-		pputs(s, ")\n");
+		stream_puts(s, ")\n");
 	    }
 	    }
 	}
@@ -283,11 +283,11 @@ pdf_write_FontDescriptor(gx_device_pdf *pdev, const pdf_font_descriptor_t *pfd)
 		FontFile_key = "/FontFile3";
 		break;
 	    }
-	    pputs(s, FontFile_key);
+	    stream_puts(s, FontFile_key);
 	    pprintld1(s, " %ld 0 R", pfd->FontFile_id);
 	}
     }
-    pputs(s, ">>\n");
+    stream_puts(s, ">>\n");
     pdf_end_separate(pdev);
     return code;
 }
@@ -312,7 +312,7 @@ pdf_write_font_resource(gx_device_pdf *pdev, const pdf_font_t *pef,
     s = pdev->strm;
     switch (pef->FontType) {
     case ft_composite:
-	pputs(s, "<</Subtype/Type0");
+	stream_puts(s, "<</Subtype/Type0");
 	goto bfname;
     case ft_encrypted:
     case ft_encrypted2: {
@@ -324,35 +324,35 @@ pdf_write_font_resource(gx_device_pdf *pdev, const pdf_font_t *pef,
 	 * instances happily if they are tagged as Type1 (!).
 	 */
 #if 0
-	    pputs(s, "<</Subtype/MMType1");
+	    stream_puts(s, "<</Subtype/MMType1");
 	    /****** NAME IS WRONG ******/
 #else
-	    pputs(s, "<</Subtype/Type1");
+	    stream_puts(s, "<</Subtype/Type1");
 #endif
 	} else {
-	    pputs(s, "<</Subtype/Type1");
+	    stream_puts(s, "<</Subtype/Type1");
 	}
     }
     bfname:
-	pputs(s, "/BaseFont");
+	stream_puts(s, "/BaseFont");
 	pdf_put_name(pdev, pbfname->data, pbfname->size);
 	break;
     case ft_CID_encrypted:
-	pputs(s, "<</Subtype/CIDFontType0");
+	stream_puts(s, "<</Subtype/CIDFontType0");
 	/****** REQUIRES FONT TO EXIST ******/
 	pdf_write_CIDSystemInfo(pdev, &((const gs_font_cid0 *)pfd->base_font)->
 				cidata.common.CIDSystemInfo);
 	goto bfname;
     case ft_CID_TrueType:
-	pputs(s, "<</Subtype/CIDFontType2");
+	stream_puts(s, "<</Subtype/CIDFontType2");
 	/****** REQUIRES FONT TO EXIST ******/
 	pdf_write_CIDSystemInfo(pdev, &((const gs_font_cid2 *)pfd->base_font)->
 				cidata.common.CIDSystemInfo);
 	goto ttname;
     case ft_TrueType:
-	pputs(s, "<</Subtype/TrueType");
+	stream_puts(s, "<</Subtype/TrueType");
     ttname:
-	pputs(s, "/BaseFont");
+	stream_puts(s, "/BaseFont");
 	/****** WHAT ABOUT STYLE INFO? ******/
 	pdf_put_name(pdev, pbfname->data, pbfname->size);
 	break;
@@ -374,10 +374,10 @@ pdf_write_font_resource(gx_device_pdf *pdev, const pdf_font_t *pef,
 	pdf_end_separate(pdev);
 	pdf_open_separate(pdev, diff_id);
 	s = pdev->strm;
-	pputs(s, "<</Type/Encoding");
+	stream_puts(s, "<</Type/Encoding");
 	if (pef->BaseEncoding != ENCODING_INDEX_UNKNOWN)
 	    pprints1(s, "/BaseEncoding/%s", encoding_names[pef->BaseEncoding]);
-	pputs(s, "/Differences[");
+	stream_puts(s, "/Differences[");
 	for (i = 0; i < 256; ++i)
 	    if (pef->Differences[i].str.data != 0) {
 		if (i != prev + 1)
@@ -386,11 +386,11 @@ pdf_write_font_resource(gx_device_pdf *pdev, const pdf_font_t *pef,
 			     pef->Differences[i].str.size);
 		prev = i;
 	    }
-	pputs(s, "]");
+	stream_puts(s, "]");
     } else if (pef->BaseEncoding != ENCODING_INDEX_UNKNOWN) {
 	pprints1(s, "/Encoding/%s", encoding_names[pef->BaseEncoding]);
     }
-    pputs(s, ">>\n");
+    stream_puts(s, ">>\n");
     return pdf_end_separate(pdev);
 }
 
