@@ -17,7 +17,7 @@
   copies.
 */
 
-/*$RCSfile: gstype42.c,v $ $Revision: 1.7.2.4 $ */
+/*$RCSfile: gstype42.c,v $ $Revision: 1.7.2.5 $ */
 /* Type 42 (TrueType) font library routines */
 #include "memory_.h"
 #include "gx.h"
@@ -787,7 +787,10 @@ check_component(uint glyph_index, const gs_matrix_fixed *pmat,
 	return 0;
     numContours = S16(gdata);
     if (numContours >= 0) {
-	simple_glyph_metrics(pfont, glyph_index, pfont->WMode, sbw);
+        /* Only sbw[0] is used in append_simple. 
+	   In order to set sbw[0], 0 is passed to 
+	   simple_glyph_metrics as wmode. */
+	simple_glyph_metrics(pfont, glyph_index, 0, sbw);
 	code = append_simple(gdata, sbw, pmat, ppath, ppts, pfont);
 	return (code < 0 ? code : 0); /* simple */
     }
