@@ -17,7 +17,7 @@
   copies.
 */
 
-/*$RCSfile: zchar.c,v $ $Revision: 1.3.2.2 $ */
+/*$RCSfile: zchar.c,v $ $Revision: 1.3.2.3 $ */
 /* Character operators */
 #include "ghost.h"
 #include "oper.h"
@@ -404,7 +404,12 @@ op_show_finish_setup(i_ctx_t *i_ctx_p, gs_text_enum_t * penum, int npop,
 		       TEXT_FROM_STRING | TEXT_DO_NONE | TEXT_INTERVENE) &&
 	SHOW_IS_ALL_OF(penum, TEXT_FROM_STRING | TEXT_RETURN_WIDTH) &&
 	(glyph = gs_text_current_glyph(osenum)) != gs_no_glyph &&
-	glyph >= gs_min_cid_glyph
+	glyph >= gs_min_cid_glyph &&
+	/* If a show operator with changing the currentfont is run,
+	   we don't have to raise a rangecheck error, per the Red Book. 
+	   We check the currentfont is changed in the proc of a cshow here. */
+	gs_default_same_font (gs_text_current_font(osenum), 
+			      gs_text_current_font(penum), true)
 	) {
 	gs_text_params_t text;
 
