@@ -17,12 +17,17 @@
 # requires that the copyright notice and this notice be preserved on all
 # copies.
 
-# $Id: cvs2hist.py,v 1.3 2000/09/19 18:10:51 lpd Exp $
+# $Id: cvs2hist.py,v 1.3.2.3 2002/02/06 23:34:29 giles Exp $
 
 # Convert the change notices in a CVS repository to the Ghostscript
 # History.htm file format.  Based on cvs2log.py by Henry Stiles
 # <henrys@artifex.com>.
 
+# Typical usage is: cvs2hist.py -j gs7_03 -v 7.04 > doc/Changes.htm.
+# The -j argument specifies a reference revision tag. This selects
+# log messages on the current branch (as determined by cvs status)
+# that are more recent than the reference tag.
+
 # ---------------- Generic utilities ---------------- #
 
 # Convert a date/time string in RCS format (yyyy/mm/dd hh:mm:ss) to
@@ -58,6 +63,20 @@ def LineBrokenText(indent, line_length, items):
             pos = pos + 1 + len(item)
     return lines[1:] + '\n'  # delete the unwanted first space
 
+# 'Normalize' the text of a named anchor to comply with spec
+def NormalizeAnchor(name):
+    import re
+    return re.sub('[^0-9a-zA-Z-_\.]', '_', name)
+
+# replace special characters with html entities
+# FIXME: isn't there a library call for this?
+def HTMLEncode(line):
+    import string
+    line = string.join(string.split(line,'&'),'&amp;')
+    line = string.join(string.split(line,'<'),'&lt;')
+    line = string.join(string.split(line,'>'),'&gt;')
+    return line
+
 # ---------------- CVS-specific code ---------------- #
 
 # Return the CVS repository root directory (the argument for -d in CVS
@@ -106,7 +125,7 @@ SourceGroupPatterns = map(lambda pair: (re.compile(pair[0]), pair[1]), [
     ["^examples/", "Interpreter"],
     ["^man/", "Documentation"],
     ["^toolbin/", "Procedures"],
-    ["^lib/pdf_.*[.]ps$", "Interpreter (PDF)"],
+    ["^lib/pdf_.*[.]ps$", "PDF Interpreter"],
     ["^lib/gs_.*[.]ps$", "Interpreter"],
     ["^lib/ht_.*[.]ps$", "Interpreter"],
     ["^lib/.*[.]upp$", "Drivers"],
@@ -128,7 +147,7 @@ SourceGroupPatterns = map(lambda pair: (re.compile(pair[0]), pair[1]), [
     ["^src/d[pw]", "Interpreter"],
     ["^src/.*[.]cpp$", "Interpreter"],
     ["^src/.*[.]c$", "Utilities"],
-    ["", "???Other???"]    # This pattern must appear at the end.
+    ["", "Other"]    # This pattern must appear at the end.
     ])
 def SourceFileGroup(filename, sources):
     if sources.has_key(filename):
@@ -139,17 +158,15 @@ def SourceFileGroup(filename, sources):
 
 # Create a version TOC.
 def VersionTOC(version, version_date, groups):
-    start = '<blockquote><ul>\n<li>'
+    start = '<ul>\n<li>'
     toc = ''
     for group in groups:
-        toc = toc + '    <a href="#' + version + ' ' + group + '">' + group + '</a>,\n'
-    return start + toc[4:-2] + '\n</ul>\n</ul></blockquote>'
+        toc = toc + '    <a href="#' + NormalizeAnchor(version + '-' + group) + '">' + group + '</a>,\n'
+    return start + toc[4:-2] + '\n</ul>\n'
 
 # Create a change log group header.
 def ChangeLogGroupHeader(group, previous_group, version):
-    if version == None:
-        return '\n****** ' + group + ' ******'
-    header = '\n<h2><a name="' + version + ' ' + group + '"></a>' + group + '</h2><pre>'
+    header = '\n<h2><a name="' + NormalizeAnchor(version + '-' + group) + '"></a>' + group + '</h2><pre>'
     if previous_group != None:
         header = '\n</pre>' + header[1:]
     return header
@@ -177,13 +194,16 @@ def BuildPatch(cvs_command, revision, rcs_file):
     return os.popen(patch_command, 'r').readlines()
 
 # Create an individual history entry.
-def ChangeLogEntry(cvs_command, author, date, rev_files, description_lines, prefix, indent, line_length, patch):
+def ChangeLogEntry(cvs_command, author, date, rev_files, description_lines, prefix, indent, line_length, patch, text_option):
     import string, time
     # Add the description.
     description = ''
     for line in description_lines:
         description = description + line[:-1] + ' '  # drop trailing \n
-    entry = string.split(string.strip(description))
+    if text_option == 0:
+	entry = string.split(string.strip(HTMLEncode(description)))
+    else:
+	entry = string.split(string.strip(description))
     entry[0] = prefix + entry[0]
     # Add the list of RCS files and revisions.
     items = []
@@ -204,47 +224,93 @@ def ChangeLogEntry(cvs_command, author, date, rev_files, description_lines, pref
                 entry = entry + patch_line
     return entry
 
+# Find the current revision for each file in the current local copy.
+def GetCurrentRevisions(status_command, cvs_repository):
+    import os, re, string
+
+    cvs_path = string.split(cvs_repository, ':')[-1]
+    cvs_dir_n = len(string.split(cvs_path, '/')) + 1
+    status_file = os.popen(status_command, 'r')
+    rev_re = re.compile(r'\s*Repository revision:\s+(\S+)\s+(\S+),v')
+    current_revisions = {}
+    while 1:
+        line = status_file.readline()
+        if line == '': break
+        m = rev_re.match(line)
+        if m:
+            rev = m.group(1)
+            fn = string.join(string.split(m.group(2), '/')[cvs_dir_n:], '/')
+            current_revisions[fn] = rev
+    status_file.close()
+    return current_revisions
+
+# Return value: true if rev2 is a later revision derived from rev1.
+def RevisionLater(rev1, rev2):
+    import string
+    rev1_l = string.split(rev1, '.')
+    rev2_l = string.split(rev2, '.')
+
+    if len(rev2_l) < len(rev1_l):
+        return 0
+    for i in range(len(rev1_l)):
+        if i == len(rev2_l): return 1
+        if int(rev2_l[i]) < int(rev1_l[i]): return 0
+        if int(rev2_l[i]) > int(rev1_l[i]): return i == len(rev1_l) - 1
+    return 1
+
 # Build the combined CVS log.  We return an array of tuples of
-# (date, author, description, rcs_file, revision, tags).
+# (date, author, description, rcs_file, revision, tags, ref_rev).
 # The date is just a string in RCS format (yyyy/mm/dd hh:mm:ss).
 # The description is a sequence of text lines, each terminated with \n.
-def BuildLog(log_date_command):
-    import os, regex, string
+def BuildLog(log_date_command, ref_tag):
+    import os, re, string
 
     reading_description = 0
     reading_tags = 0
     description = []
     log = []
-    tag_pattern = regex.compile("^	\([^:]+\): \([0-9.]+\)\n$")
+    tag_pattern = re.compile("^	([^:]+): ([0-9.]+)\n$")
+    branches_re = re.compile("^branches:")
 
-    for line in os.popen(log_date_command, 'r').readlines():
+    log_file = os.popen(log_date_command, 'r')
+    while 1:
+        line = log_file.readline()
+        if line == '': break
 	if line[:5] == '=====' or line[:5] == '-----':
 	    if description != []:
                 try:
                     my_tags = tags[revision]
                 except KeyError:
                     my_tags = []
-		log.append(date, author, description, rcs_file, revision, my_tags)
+		log.append((date, author, description, rcs_file, revision, my_tags, ref_rev))
 	    reading_description = 0
 	    description = []
             continue
 	if reading_description:
+            # Omit initial empty description lines and branches info.
+            if description == [] and (line == '\n' or branches_re.match(line)):
+                continue
 	    description.append(line)
             continue
         if reading_tags:
-            if tag_pattern.match(line) > 0:
-                tag = tag_pattern.group(1)
-                revs = string.splitfields(tag_pattern.group(2), ", ")
-                for rev in revs:
-                    try:
-                        tags[rev].append(tag)
-                    except KeyError:
-                        tags[rev] = [tag]
+            match = tag_pattern.match(line)
+            if match == None:
+                reading_tags = 0
                 continue
-            reading_tags = 0
+            tag = match.group(1)
+            revs = string.splitfields(match.group(2), ", ")
+            if tag == ref_tag:
+                ref_rev = revs[0]
+            for rev in revs:
+                try:
+                    tags[rev].append(tag)
+                except KeyError:
+                    tags[rev] = [tag]
+            continue
 	if line[:len("Working file: ")] == "Working file: ":
 	    rcs_file = line[len("Working file: "):-1]
             tags = {}
+            ref_rev = None
 	elif line[:len("revision ")] == "revision ":
 	    revision = line[len("revision "):-1]
 	elif line[:len("date: ")] == "date: ":
@@ -254,10 +320,13 @@ def BuildLog(log_date_command):
 	    reading_description = 1
         elif line[:len("symbolic names:")] == "symbolic names:":
             reading_tags = 1
+    log_file.close()
+
     return log
 
 # ---------------- Main program ---------------- #
 
+# make sure the group names normalize to distinct anchors!
 GroupOrder = {
     "Documentation" : 1,
     "Procedures" : 2,
@@ -266,23 +335,25 @@ GroupOrder = {
     "Platforms" : 5,
     "Fonts" : 6,
     "PDF writer" : 7,
-    "Interpreter (PDF)" : 8,
+    "PDF Interpreter" : 8,
     "Interpreter" : 9,
     "Streams" : 10,
-    "Library" : 11
+    "Library" : 11,
+    "Other" : 12
     }
 
 # Parse command line options and build logs.
 def main():
-    import sys, getopt, time, string, regex, regsub
+    import sys, getopt, time, string, re
     try:
-	opts, args = getopt.getopt(sys.argv[1:], "C:d:Hi:l:Mpr:v:",
+	opts, args = getopt.getopt(sys.argv[1:], "C:d:Hi:l:Mptr:v:j:",
 				   ["CVS_command",
 				    "date",
                                     "indent",
                                     "length",
                                     "Merge",
 				    "patches",     #### not yet supported
+				    "text",
 				    "rlog_options", #### not yet supported
                                     "version"
 				    ])
@@ -292,7 +363,8 @@ def main():
 	print msg
 	print "Usage: cvs2hist ...options..."
 	print "Options: [-C CVS_command] [-d rcs_date] [-i indent] [-l length]"
-	print "         [-M] [-p] [-r rlog_options] [-v version]"
+	print "         [-M] [-p] [-t] [-r rlog_options] [-v version]"
+        print "         [-j tag]"
 	sys.exit(2)
 
     # Set up defaults for all of the command line options.
@@ -306,8 +378,10 @@ def main():
     length = 76
     merge = 0
     patches = 0
-    rlog_options  =  0
-    version = None
+    rlog_options = ""
+    text_option = 0;
+    ref_tag = None;
+    version = "CVS"
     # override defaults if specified on the command line
     for o, a in opts:
 	if o == '-C' : cvs_command = a
@@ -316,22 +390,18 @@ def main():
 	elif o == '-l' : length = string.atoi(a)
         elif o == '-M' : merge = 1
         elif o == '-p' : patches = 1
+	elif o == '-t' : text_option = 1
 	elif o == '-r' : rlog_options = a
 	elif o == '-v' : version = a
+        elif o == '-j' : ref_tag = a
 	else: print "getopt should have failed already"
 
+    status_command = cvs_command + ' -d ' + cvs_repository + ' -Q status'
+    cur_revisions = GetCurrentRevisions(status_command, cvs_repository)
     # set up the cvs log command arguments.
-    log_date_command = cvs_command + ' -d ' + cvs_repository + ' -Q log ' + date_option
+    log_date_command = cvs_command + ' -d ' + cvs_repository +' -Q log ' + date_option + ' ' + rlog_options
     # Acquire the log data.
-    log = BuildLog(log_date_command)
-    # By default, if no date option is specified, produce output for
-    # changes since the most recent tagged version.  To avoid a second
-    # pass over the CVS repository, we do the filtering locally.
-    min_date = '0000/00/00 00:00:00'
-    if date_option == "":
-        for date, author, text_lines, file, revision, tags in log:
-            if len(tags) != 0 and date > min_date:
-                min_date = date
+    log = BuildLog(log_date_command, ref_tag)
     # Scan the makefiles to find source file names.
     sources = {}
     sources = ScanMakefileForSources('src/lib.mak', sources, "Library")
@@ -347,9 +417,13 @@ def main():
     # Sort the log by group, then by fix/non-fix, then by date, then by
     # description (to group logically connected files together).
     sorter = []
-    group_pattern = regex.compile("^(\([^)]+\))[ ]+")
-    for date, author, text_lines, file, revision, tags in log:
-        if date <= min_date:
+    group_pattern = re.compile("^(\([^)]+\))[ ]+")
+    for date, author, text_lines, file, revision, tags, ref_rev in log:
+        if not cur_revisions.has_key(file):
+            continue
+        if not RevisionLater(revision, cur_revisions[file]):
+            continue
+        if ref_rev and (ref_rev == revision or not RevisionLater(ref_rev, revision)):
             continue
         line = ''
         while len(text_lines) > 0:
@@ -359,9 +433,10 @@ def main():
             text_lines[:1] = []
         if merge:
             group = "(all)"
-        elif group_pattern.match(text_lines[0]) > 0:
-            group = group_pattern.group(1)
-            text_lines[0] = text_lines[0][len(group_pattern.group(0)):]
+        elif group_pattern.match(text_lines[0]) != None:
+            match = group_pattern.match(text_lines[0])
+            group = match.group(1)
+            text_lines[0] = text_lines[0][len(match.group(0)):]
         else:
             group = SourceFileGroup(file, sources)
         try:
@@ -372,18 +447,22 @@ def main():
             text_lines[0] = line[4:] + '\n'
             section = 0
         else:
-            section = regex.match("^Fix", text_lines[0]) < 0
-        sorter.append(group_order, section, date, group, text_lines, author, file, revision, tags)
+            section = re.match("^Fix", text_lines[0]) < 0
+        sorter.append((group_order, section, date, group, text_lines, author, file, revision, tags))
     sorter.sort()
     log = sorter
     # Print the HTML header.
     time_now = time.localtime(time.time())
     version_date = time.strftime('%Y-%m-%d', time_now)
     version_time = time.strftime('%Y-%m-%d %H:%M:%S', time_now)
-    if version != None:
+    if text_option == 0:
+	print "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">"
         print "<html><head>"
         print "<title>Ghostscript " + version + " change history as of " + version_time + "</title>"
+	print "<link rel=stylesheet type=\"text/css\" href=\"gs.css\">"
         print "</head><body>\n"
+	print '<!-- cvs command: ' + log_date_command + ' -->\n'
+
         last_group = None
         groups = []
         for omit_group_order, section, date, group, description, author, rcs_file, revision, tags in log:
@@ -404,15 +483,18 @@ def main():
     for omit_group_order, section, date, group, description, author, rcs_file, revision, tags in log:
         if group != last_group:
             if rev_files != []:
-                print ChangeLogEntry(cvs_command, last_author, last_date, rev_files, last_description, prefix, indent, length, patches)[:-1]
+                print ChangeLogEntry(cvs_command, last_author, last_date, rev_files, last_description, prefix, indent, length, patches, text_option)[:-1]
                 rev_files = []
-            print ChangeLogGroupHeader(group, last_group, version)
+	    if text_option == 0:
+		print ChangeLogGroupHeader(group, last_group, version)
+	    else:
+		print '\n****** ' + group + ' ******'
             last_group = group
             last_section = None
             last_description = None
         if section != last_section:
             if rev_files != []:
-                print ChangeLogEntry(cvs_command, last_author, last_date, rev_files, last_description, prefix, indent, length, patches)[:-1]
+                print ChangeLogEntry(cvs_command, last_author, last_date, rev_files, last_description, prefix, indent, length, patches, text_option)[:-1]
                 rev_files = []
 	    (header, prefix) = ChangeLogSectionHeader(section, last_section, version)
             if header != None:
@@ -421,20 +503,20 @@ def main():
             last_description = None
 	if author != last_author or description != last_description or abs(RCSDateToSeconds(date) - RCSDateToSeconds(last_date)) >= 3:
             if rev_files != []:
-                print ChangeLogEntry(cvs_command, last_author, last_date, rev_files, last_description, prefix, indent, length, patches)[:-1]
+                print ChangeLogEntry(cvs_command, last_author, last_date, rev_files, last_description, prefix, indent, length, patches, text_option)[:-1]
                 rev_files = []
             last_author = author
             last_date = date
             last_description = description
 	# Accumulate the revisions and RCS files.
-        rev_files.append(revision, rcs_file)
+        rev_files.append((revision, rcs_file))
 
     # print the last entry if there is one (i.e. the last two entries
     # have the same author and date)
     if rev_files != []:
-        print ChangeLogEntry(cvs_command, last_author, last_date, rev_files, last_description, prefix, indent, length, patches)[:-1]
+        print ChangeLogEntry(cvs_command, last_author, last_date, rev_files, last_description, prefix, indent, length, patches, text_option)[:-1]
     # Print the HTML trailer.
-    if version != None:
+    if text_option == 0:
         print "\n</pre></body></html>"
 
 if __name__ == '__main__':
